import { GenericProtocol } from '~/modules/comms-adapter/protocol';

/**
 *
 */
export class ExampleClientProtocol extends GenericProtocol {
  constructor(schema, services) {
    super(schema, services);
    // bootstrap any injected services
  }

  /**
   * Process a message received from the backbone
   *
   * This method is overridden to take appropriate
   * action for each message type.
   *
   * Further methods can then be defined to handle
   * each message type.
   *
   * You can use this to take action directly or
   * transform that data to invoke an existing process.
   * @param {string} type
   * @param {object} message
   * @returns
   */
  decode(type, message) {
    switch (type) {
      case 'VehicleStatus':
        this.decodeVehicleStatus(message);
        break;
      case 'VehicleMission':
        this.decodeVehicleMission(message);
        break;
    }
    return message;
  }

  /**
   * Transform local data into a message conforming to the protocol schema
   *
   * When a client event occurs the local data is passed through
   * encode to handle the translation from the native client format
   * into a message conforming to the protocol schema.
   * @param {string} type
   * @param {object} message
   * @returns
   */
  encode(type, message) {
    return message;
  }

  /**
   * Act upon a received VehicleStatus message
   * @param {object} message
   * @returns {object}
   */
  decodeVehicleStatus(message) {
    const battery = message.battery_percentage;
    message.battery_rag_status =
      battery > 20 ? 'green' : battery > 10 ? 'amber' : 'red';
    this.services.bridge.$emit('soar.vehicle.status', message);
    return message;
  }

  /**
   * Act upon a received VehicleMission message
   * @param {object} message
   * @returns {object}
   */
  decodeVehicleMission(message) {
    this.services.bridge.$emit('soar.vehicle.mission', message);
    return message;
  }

  /**
   * Transform local data into a VehicleStatus message
   * @param {object} message
   * @returns {object}
   */
  encodeVehicleStatus(message) {
    return message;
  }
}
